/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2018 hsz Jakub Chrzanowski <jakub@hsz.mobi>
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.intellij.openapi.vcs.changes.ignore.lang;

import com.intellij.openapi.util.text.StringUtil;
import org.jetbrains.annotations.NonNls;
import org.jetbrains.annotations.Nullable;

public enum Syntax {
  GLOB, REGEXP;

  @NonNls
  private static final String KEY = "syntax:";

  @Nullable
  public static Syntax find(@Nullable String name) {
    if (name == null) {
      return null;
    }
    try {
      return valueOf(StringUtil.toUpperCase(name));
    }
    catch (IllegalArgumentException iae) {
      return null;
    }
  }

  @Override
  public String toString() {
    return StringUtil.toLowerCase(super.toString());
  }

  /**
   * Returns {@link com.intellij.openapi.vcs.changes.ignore.psi.IgnoreTypes#SYNTAX} element presentation.
   *
   * @return element presentation
   */
  public String getPresentation() {
    return StringUtil.join(KEY, " ", toString());
  }
}
